@@ -1,4 +1,6 @@
-# Copyright 2021 nakamura_yuki
+# Copyright (c) 2021-2025, NakaMetPy Develoers.
+# Distributed under the terms of the BSD 3-Clause License.
+# SPDX-License-Identifier: BSD-3-Clause
 # 
 # This program comes from Qiita article
 # URL: https://qiita.com/vpcf/items/b680f504cfe8b6a64222
@@ -10,6 +12,8 @@
 # 　(自作の？)エラーを表示させるようにする
 #
 from matplotlib.colors import LinearSegmentedColormap, ListedColormap
+from nakametpy.constants import MPL_DEFAULT_COLOR_LIST
+import os
 import sys
 
 
@@ -17,8 +21,9 @@ _CMAX = 255
 
 def sunshine():
     r'''
-    NCLのcolor table中の `sunshine_9lev` に対応する。
-    levelは256である。
+    NCLのcolor table中の `sunshine_9lev` に対応する.  
+    
+    levelは256である.
 
     Returns
     -------
@@ -26,7 +31,7 @@ def sunshine():
     
     Notes
     -----    
-    オブジェクトは ``sunshine_256lev`` という名前でも受け取れる。
+    オブジェクトは ``sunshine_256lev`` という名前でも受け取れる.
 
     |sunshine|
 
@@ -50,9 +55,11 @@ def sunshine():
 
 def BrWhGr():
     r'''
-    緑白ブラウンのカラーマップ。
-    水蒸気の発散収束を表す際に便利。
-    levelは256である。
+    緑白ブラウンのカラーマップ.
+    
+    水蒸気の発散収束を表す際に便利.
+    
+    levelは256である.
 
     Returns
     -------
@@ -60,7 +67,7 @@ def BrWhGr():
     
     Notes
     -----    
-    オブジェクトは ``BrWhGr_256lev`` という名前でも受け取れる。
+    オブジェクトは ``BrWhGr_256lev`` という名前でも受け取れる.
 
     |BrWhGr|
 
@@ -88,7 +95,7 @@ def BrWhGr():
 
 
 def precip3():
-    r'''降水量をプロットする際に利用することを想定したカラーマップ。
+    r'''降水量をプロットする際に利用することを想定したカラーマップ.
 
     Returns
     -------
@@ -96,7 +103,7 @@ def precip3():
     
     Notes
     -----
-    オブジェクトは ``precip3_256lev`` という名前でも受け取れる。
+    オブジェクトは ``precip3_256lev`` という名前でも受け取れる.
 
     |precip3|
 
@@ -134,7 +141,7 @@ def precip3():
 
     
 def jma_linear():
-    r'''気象庁が降水量をプロットする際に利用しているカラーマップを模している。
+    r'''気象庁が降水量をプロットする際に利用しているカラーマップを模している.
 
     Returns
     -------
@@ -142,7 +149,7 @@ def jma_linear():
     
     Notes
     -----
-    オブジェクトは ``jma_linear_256lev`` という名前でも受け取れる。
+    オブジェクトは ``jma_linear_256lev`` という名前でも受け取れる.
 
     |jma_linear|
 
@@ -183,7 +190,7 @@ def jma_linear():
 
 
 def jma_list():
-    r'''気象庁が降水量をプロットする際に利用しているカラーマップを模している。
+    r'''気象庁が降水量をプロットする際に利用しているカラーマップを模している.
 
     Returns
     -------
@@ -191,7 +198,7 @@ def jma_list():
     
     Notes
     -----
-    オブジェクトは ``jma_list_9lev`` という名前でも受け取れる。
+    オブジェクトは ``jma_list_9lev`` という名前でも受け取れる.
 
     |jma_list|
 
@@ -216,7 +223,7 @@ def jma_list():
 
 
 def grads_default_rainbow_linear():
-    r'''GrADSデフォルトのカラーマップ。
+    r'''GrADSデフォルトのカラーマップ.
 
     Returns
     -------
@@ -224,7 +231,7 @@ def grads_default_rainbow_linear():
     
     Notes
     -----
-    オブジェクトは ``grads_default_rainbow_linear_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_default_rainbow_linear_256lev`` という名前でも受け取れる.
 
     |grads_default_rainbow_linear|
 
@@ -280,7 +287,7 @@ def grads_default_rainbow_linear():
 
 
 def grads_default_rainbow_list():
-    r'''GrADSデフォルトのカラーマップ。
+    r'''GrADSデフォルトのカラーマップ.
 
     Returns
     -------
@@ -288,7 +295,7 @@ def grads_default_rainbow_list():
     
     Notes
     -----
-    オブジェクトは ``grads_default_rainbow_list_13lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_default_rainbow_list_13lev`` という名前でも受け取れる.
 
     |grads_default_rainbow_list|
 
@@ -316,7 +323,7 @@ def grads_default_rainbow_list():
 
 
 def grads_paired():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -324,7 +331,7 @@ def grads_paired():
     
     Notes
     -----
-    オブジェクトは ``grads_paired_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_paired_256lev`` という名前でも受け取れる.
 
     |grads_paired|
 
@@ -372,7 +379,7 @@ def grads_paired():
     return LinearSegmentedColormap('grads_paired', cdict)
 
 def grads_spectral():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -380,7 +387,7 @@ def grads_spectral():
     
     Notes
     -----
-    オブジェクトは ``grads_spectral_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_spectral_256lev`` という名前でも受け取れる.
 
     |grads_spectral|
 
@@ -419,7 +426,7 @@ def grads_spectral():
     return LinearSegmentedColormap('grads_spectral', cdict)
 
 def grads_rainbow():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -427,7 +434,7 @@ def grads_rainbow():
     
     Notes
     -----
-    オブジェクトは ``grads_rainbow_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_rainbow_256lev`` という名前でも受け取れる.
 
     |grads_rainbow|
 
@@ -460,7 +467,7 @@ def grads_rainbow():
     return LinearSegmentedColormap('grads_rainbow', cdict)
 
 def grads_b2r():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -468,7 +475,7 @@ def grads_b2r():
     
     Notes
     -----
-    オブジェクトは ``grads_b2r_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_b2r_256lev`` という名前でも受け取れる.
 
     |grads_b2r|
 
@@ -495,7 +502,7 @@ def grads_b2r():
     return LinearSegmentedColormap('grads_b2r', cdict)
 
 def grads_brn2grn():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -503,7 +510,7 @@ def grads_brn2grn():
     
     Notes
     -----
-    オブジェクトは ``grads_brn2grn_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_brn2grn_256lev`` という名前でも受け取れる.
 
     |grads_brn2grn|
 
@@ -530,7 +537,7 @@ def grads_brn2grn():
     return LinearSegmentedColormap('grads_brn2grn', cdict)
 
 def grads_y2b():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -538,7 +545,7 @@ def grads_y2b():
     
     Notes
     -----
-    オブジェクトは ``grads_y2b_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_y2b_256lev`` という名前でも受け取れる.
 
     |grads_y2b|
 
@@ -565,7 +572,7 @@ def grads_y2b():
     return LinearSegmentedColormap('grads_y2b', cdict)
 
 def grads_oj2p():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -573,7 +580,7 @@ def grads_oj2p():
     
     Notes
     -----
-    オブジェクトは ``grads_oj2p_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_oj2p_256lev`` という名前でも受け取れる.
 
     |grads_oj2p|
 
@@ -600,7 +607,7 @@ def grads_oj2p():
     return LinearSegmentedColormap('grads_oj2p', cdict)
 
 def grads_terrain1():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -608,7 +615,7 @@ def grads_terrain1():
     
     Notes
     -----
-    オブジェクトは ``grads_terrain1_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_terrain1_256lev`` という名前でも受け取れる.
 
     |grads_terrain1|
 
@@ -638,7 +645,7 @@ def grads_terrain1():
     return LinearSegmentedColormap('grads_terrain1', cdict)
 
 def grads_ocean():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -646,7 +653,7 @@ def grads_ocean():
     
     Notes
     -----
-    オブジェクトは ``grads_ocean_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_ocean_256lev`` という名前でも受け取れる.
 
     |grads_ocean|
 
@@ -670,7 +677,7 @@ def grads_ocean():
     return LinearSegmentedColormap('grads_ocean', cdict)
 
 def grads_grayscale():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -678,7 +685,7 @@ def grads_grayscale():
     
     Notes
     -----
-    オブジェクトは ``grads_grayscale_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_grayscale_256lev`` という名前でも受け取れる.
 
     |grads_grayscale|
 
@@ -691,7 +698,7 @@ def grads_grayscale():
     return LinearSegmentedColormap('grads_grayscale', cdict)
 
 def grads_red():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -699,7 +706,7 @@ def grads_red():
     
     Notes
     -----
-    オブジェクトは ``grads_red_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_red_256lev`` という名前でも受け取れる.
 
     |grads_red|
 
@@ -712,7 +719,7 @@ def grads_red():
     return LinearSegmentedColormap('grads_red', cdict)
 
 def grads_green():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -720,7 +727,7 @@ def grads_green():
     
     Notes
     -----
-    オブジェクトは ``grads_green_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_green_256lev`` という名前でも受け取れる.
 
     |grads_green|
 
@@ -733,7 +740,7 @@ def grads_green():
     return LinearSegmentedColormap('grads_green', cdict)
 
 def grads_blue():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -741,7 +748,7 @@ def grads_blue():
     
     Notes
     -----
-    オブジェクトは ``grads_blue_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_blue_256lev`` という名前でも受け取れる.
 
     |grads_blue|
 
@@ -754,7 +761,7 @@ def grads_blue():
     return LinearSegmentedColormap('grads_blue', cdict)
 
 def grads_jet():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -762,7 +769,7 @@ def grads_jet():
     
     Notes
     -----
-    オブジェクトは ``grads_jet_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_jet_256lev`` という名前でも受け取れる.
 
     |grads_jet|
 
@@ -801,7 +808,7 @@ def grads_jet():
     return LinearSegmentedColormap('grads_jet', cdict)
 
 def grads_terrain2():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -809,7 +816,7 @@ def grads_terrain2():
     
     Notes
     -----
-    オブジェクトは ``grads_terrain2_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_terrain2_256lev`` という名前でも受け取れる.
 
     |grads_terrain2|
 
@@ -842,7 +849,7 @@ def grads_terrain2():
     return LinearSegmentedColormap('grads_terrain2', cdict)
 
 def grads_dark():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -850,7 +857,7 @@ def grads_dark():
     
     Notes
     -----
-    オブジェクトは ``grads_dark_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_dark_256lev`` という名前でも受け取れる.
 
     |grads_dark|
 
@@ -886,7 +893,7 @@ def grads_dark():
     return LinearSegmentedColormap('grads_dark', cdict)
 
 def grads_snow():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -894,7 +901,7 @@ def grads_snow():
     
     Notes
     -----
-    オブジェクトは ``grads_snow_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_snow_256lev`` という名前でも受け取れる.
 
     |grads_snow|
 
@@ -921,7 +928,7 @@ def grads_snow():
     return LinearSegmentedColormap('grads_snow', cdict)
 
 def grads_satellite():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -929,7 +936,7 @@ def grads_satellite():
     
     Notes
     -----
-    オブジェクトは ``grads_satellite_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_satellite_256lev`` という名前でも受け取れる.
 
     |grads_satellite|
 
@@ -956,7 +963,7 @@ def grads_satellite():
     return LinearSegmentedColormap('grads_satellite', cdict)
 
 def grads_rain():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -964,7 +971,7 @@ def grads_rain():
     
     Notes
     -----
-    オブジェクトは ``grads_rain_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_rain_256lev`` という名前でも受け取れる.
 
     |grads_rain|
 
@@ -991,7 +998,7 @@ def grads_rain():
     return LinearSegmentedColormap('grads_rain', cdict)
 
 def grads_autumn():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -999,7 +1006,7 @@ def grads_autumn():
     
     Notes
     -----
-    オブジェクトは ``grads_autumn_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_autumn_256lev`` という名前でも受け取れる.
 
     |grads_autumn|
 
@@ -1026,7 +1033,7 @@ def grads_autumn():
     return LinearSegmentedColormap('grads_autumn', cdict)
 
 def grads_cool():
-    r'''GrADSのcolormaps.gsのカラーマップ。
+    r'''GrADSのcolormaps.gsのカラーマップ.
 
     Returns
     -------
@@ -1034,7 +1041,7 @@ def grads_cool():
     
     Notes
     -----
-    オブジェクトは ``grads_cool_256lev`` という名前でも受け取れる。
+    オブジェクトは ``grads_cool_256lev`` という名前でも受け取れる.
 
     |grads_cool|
 
@@ -1059,7 +1066,7 @@ def grads_cool():
 
 
 def BlWhRe():
-    r'''blue -> white -> red のカラーマップ。
+    r'''blue -> white -> red のカラーマップ.
 
     Returns
     -------
@@ -1067,7 +1074,7 @@ def BlWhRe():
     
     Notes
     -----
-    オブジェクトは ``BlWhRe_256lev`` という名前でも受け取れる。
+    オブジェクトは ``BlWhRe_256lev`` という名前でも受け取れる.
 
     |BlWhRe|
 
@@ -1225,7 +1232,7 @@ def jma_temp_anom_white_linear():
                   (8/_ncolor, 0/_CMAX, 0/_CMAX),
                   (9/_ncolor, 33/_CMAX, 33/_CMAX),
                   (10/_ncolor, 0/_CMAX, 0/_CMAX)]}
-    return LinearSegmentedColormap('jma_temp_anom_linear', cdict).reversed()
+    return LinearSegmentedColormap('jma_temp_anom_white_linear', cdict).reversed()
 
 def jma_temp_anom_white_list():
     r'''dark blue -> blue -> light blue -> white -> yellow -> orange -> red
@@ -1238,9 +1245,9 @@ def jma_temp_anom_white_list():
     -----
     The object name is ``jma_temp_anom_white_11lev``.
 
-    |jma_temp_anom_list|
+    |jma_temp_anom_white_list|
 
-    .. |jma_temp_anom_list| image:: ./img/jma_temp_anom_white_list.png
+    .. |jma_temp_anom_white_list| image:: ./img/jma_temp_anom_white_list.png
         :width: 600
 
     See Also
@@ -1258,7 +1265,7 @@ def jma_temp_anom_white_list():
             [1.0, 0.6, 0.0],
             [1.0, 0.10196078431372549, 0.10196078431372549],
             [0.5686274509803921, 0, 0.3254901960784314]]
-    return ListedColormap(clist, 'jma_temp_anom_list')
+    return ListedColormap(clist, 'jma_temp_anom_white_list')
 
 def jma_precip_anom_linear():
     r'''brown -> orange -> white -> limegreen -> green -> darkgreen
@@ -1837,6 +1844,183 @@ def jma_BlWhRe_list():
             [1.0, 0.1568627450980392, 0.0]]
     return ListedColormap(clist, 'jma_BlWhRe_list')
 
+def jwa_precip():
+    r'''日本気象協会(JWA)のレーダー雨量のカラーマップ.
+
+    Returns
+    -------
+    cmap:  `matplotlib.colors.LinearSegmentedColormap`
+    
+    Notes
+    -----
+    オブジェクトは ``jwa_precip_256lev`` という名前でも受け取れる.
+
+    |jwa_precip|
+
+    .. |jwa_precip| image:: ./img/jwa_precip.png
+        :width: 600
+    '''
+    cdict = {'blue': [
+        (0.0, 1.0, 1.0),
+        (0.17, 1.0, 1.0),
+        (0.33, 0.0, 0.0),
+        (0.5, 0.0, 0.0),
+        (0.67, 0.0, 0.0),
+        (0.83, 1.0, 1.0),
+        (1.0, 0.0, 0.0),
+      ],
+
+    'green': [
+        (0.0, 1.0, 1.0),
+        (0.17, 0.0, 0.0),
+        (0.33, 0.5, 0.5),
+        (0.5, 1.0, 1.0),
+        (0.67, 0.5, 0.5),
+        (0.83, 0.0, 0.0),
+        (1.0, 0.0, 0.0),
+      ],
+
+    'red': [
+        (0.0, 0.0, 0.0),
+        (0.17, 0.0, 0.0),
+        (0.33, 0.0, 0.0),
+        (0.5, 1.0, 1.0),
+        (0.67, 1.0, 1.0),
+        (0.83, 1.0, 1.0),
+        (1.0, 1.0, 1.0),
+      ]}
+    return LinearSegmentedColormap('jwa_precip', cdict)
+
+def cmthermal():
+    r'''Qiitaに投稿された、温度を表す理想カラーマップ.
+    
+    URL:`リンク <https://qiita.com/nokos/items/6551b3d3b46be73496cf#python-matplotlib-%E3%81%A7%E3%81%AE%E5%AE%9F%E8%A3%85>`__
+
+    Returns
+    -------
+    cmap:  `matplotlib.colors.LinearSegmentedColormap`
+    
+    Notes
+    -----
+    オブジェクトは ``cmthermal_256lev`` という名前でも受け取れる.
+
+    |cmthermal|
+
+    .. |cmthermal| image:: ./img/cmthermal.png
+        :width: 600
+    '''
+    cdict = {'blue': [
+        (0.0, 117/_CMAX, 117/_CMAX),
+        (0.25, 185/_CMAX, 185/_CMAX),
+        (0.5, 53/_CMAX, 53/_CMAX),
+        (0.75, 139/_CMAX, 139/_CMAX),
+        (1.0, 34/_CMAX, 34/_CMAX),
+      ],
+
+    'green': [
+        (0.0, 63/_CMAX, 63/_CMAX),
+        (0.25, 143/_CMAX, 143/_CMAX),
+        (0.5, 226/_CMAX, 226/_CMAX),
+        (0.75, 78/_CMAX, 78/_CMAX),
+        (1.0, 14/_CMAX, 14/_CMAX),
+      ],
+
+    'red': [
+        (0.0, 28/_CMAX, 28/_CMAX),
+        (0.25, 6/_CMAX, 6/_CMAX),
+        (0.5, 241/_CMAX, 241/_CMAX),
+        (0.75, 214/_CMAX, 214/_CMAX),
+        (1.0, 115/_CMAX, 115/_CMAX),
+      ]}
+    return LinearSegmentedColormap('jwa_precip', cdict)
+
+def weathernews_precip_list():
+    r'''気象庁が降水量をプロットする際に利用しているカラーマップを模している.
+
+    Returns
+    -------
+    cmap:  `matplotlib.colors.ListedColormap`
+    
+    Notes
+    -----
+    オブジェクトは ``weathernews_precip_list_9lev`` という名前でも受け取れる.
+
+    |weathernews_precip_list|
+
+    .. |weathernews_precip_list| image:: ./img/weathernews_precip_list.png
+        :width: 600
+
+    See Also
+    --------
+    jma_linear
+    '''
+    clist = [
+          [244/_CMAX, 244/_CMAX, 244/_CMAX],
+          [154/_CMAX, 235/_CMAX, 255/_CMAX],
+          [ 72/_CMAX, 225/_CMAX, 255/_CMAX],
+          [ 37/_CMAX, 174/_CMAX, 255/_CMAX],
+          [  0/_CMAX, 244/_CMAX,  46/_CMAX],
+          [250/_CMAX, 247/_CMAX,  20/_CMAX],
+          [255/_CMAX, 102/_CMAX, 102/_CMAX],
+          [224/_CMAX,   0/_CMAX,   0/_CMAX],
+        ]
+    return ListedColormap(clist, 'weathernews_precip_list')
+
+def weathernews_precip_linear():
+    r'''気象庁が降水量をプロットする際に利用しているカラーマップを模している.
+
+    Returns
+    -------
+    cmap:  `matplotlib.colors.LinearSegmentedColormap`
+    
+    Notes
+    -----
+    オブジェクトは ``weathernews_precip_linear_256lev`` という名前でも受け取れる.
+
+    |weathernews_precip_linear|
+
+    .. |weathernews_precip_linear| image:: ./img/weathernews_precip_linear.png
+        :width: 600
+
+    See Also
+    --------
+    jma_linear
+    '''
+    cdict = {
+    'red': [
+        (0/7, 244/_CMAX, 244/_CMAX),
+        (1/7, 154/_CMAX, 154/_CMAX),
+        (2/7, 72/_CMAX, 72/_CMAX),
+        (3/7, 37/_CMAX, 37/_CMAX),
+        (4/7, 0/_CMAX, 0/_CMAX),
+        (5/7, 250/_CMAX, 250/_CMAX),
+        (6/7, 255/_CMAX, 255/_CMAX),
+        (7/7, 224/_CMAX, 224/_CMAX),
+      ],
+
+    'green': [
+        (0/7, 244/_CMAX, 244/_CMAX),
+        (1/7, 235/_CMAX, 235/_CMAX),
+        (2/7, 225/_CMAX, 225/_CMAX),
+        (3/7, 174/_CMAX, 174/_CMAX),
+        (4/7, 244/_CMAX, 244/_CMAX),
+        (5/7, 247/_CMAX, 247/_CMAX),
+        (6/7, 102/_CMAX, 102/_CMAX),
+        (7/7,   0/_CMAX,   0/_CMAX),
+      ],
+    
+    'blue': [
+        (0/7, 244/_CMAX, 244/_CMAX),
+        (1/7, 255/_CMAX, 255/_CMAX),
+        (2/7, 255/_CMAX, 255/_CMAX),
+        (3/7, 255/_CMAX, 255/_CMAX),
+        (4/7,  46/_CMAX,  46/_CMAX),
+        (5/7,  20/_CMAX,  20/_CMAX),
+        (6/7, 102/_CMAX, 102/_CMAX),
+        (7/7,   0/_CMAX,   0/_CMAX),
+      ],
+    }
+    return LinearSegmentedColormap('weathernews_precip_linear', cdict)
 
 sunshine_256lev = sunshine()
 BrWhGr_256lev = BrWhGr()
@@ -1885,8 +2069,13 @@ jma_snow_anom_white_256lev = jma_snow_anom_white_linear()
 jma_snow_anom_white_11lev = jma_snow_anom_white_list()
 jma_BlWhRe_256lev = jma_BlWhRe_linear()
 jma_BlWhRe_11lev = jma_BlWhRe_list()
+jwa_precip_256lev = jwa_precip()
+cmthermal_256lev = cmthermal()
+weathernews_precip_linear_256lev = weathernews_precip_linear()
+weathernews_precip_list_13lev = weathernews_precip_list()
 
-cmap_list = [sunshine_256lev,
+cmap_list = [
+            sunshine_256lev,
             BrWhGr_256lev,
             BlWhRe_256lev,
             precip3_256lev,
@@ -1932,7 +2121,12 @@ cmap_list = [sunshine_256lev,
             jma_snow_anom_white_256lev,
             jma_snow_anom_white_11lev,
             jma_BlWhRe_256lev,
-            jma_BlWhRe_11lev,]
+            jma_BlWhRe_11lev,
+            jwa_precip_256lev,
+            cmthermal_256lev,
+            weathernews_precip_linear_256lev,
+            weathernews_precip_list_13lev,
+          ]
 
 
 cmap_names = ['sunshine',
@@ -1982,13 +2176,17 @@ cmap_names = ['sunshine',
             'jma_snow_anom_white_list',
             'jma_BlWhRe_linear',
             'jma_BlWhRe_list',
+            'jwa_precip',
+            'cmthermal',
+            'weathernews_precip_linear',
+            'weathernews_precip_list',
             ]
 
 
 def get_colormap(name):
-    r'''カラーマップを得る関数。
+    r'''カラーマップを得る関数.
 
-    引数の名前は ``get_colormap_list`` で得ることが出来る。
+    引数の名前は ``get_colormap_list`` で得ることが出来る.
 
     Parameters
     ----------
@@ -2009,8 +2207,9 @@ def get_colormap(name):
         print('No such colormap in nakametpy.')
         return sys.exit(1)
 
+
 def get_colormap_list():
-    r'''カラーマップ名のリストを得る関数。
+    r'''カラーマップ名のリストを得る関数.
 
     Returns
     -------
@@ -2019,12 +2218,13 @@ def get_colormap_list():
     '''
     return cmap_names
 
-def _plot_each_colorbar(cmap_name, output='../../docs/img'):
-    r'''nakametpy.cmapにあるカラーマップのカラーバーをプロットする関数。
 
-    ドキュメンテーション掲載用。
+def _plot_each_colorbar(cmap_name, output=os.path.join(os.path.dirname(__file__), '../../docs/img')):
+    r'''nakametpy.cmapにあるカラーマップのカラーバーをプロットする関数.
 
-    nakametpy.cmapのmain()で実行される。
+    ドキュメンテーション掲載用.
+
+    nakametpy.cmapのmain()で実行される.
     
     '''
     import matplotlib.pyplot as plt
@@ -2052,8 +2252,6 @@ def _plot_each_colorbar(cmap_name, output='../../docs/img'):
     plt.close(fig)
 
 
-MPL_DEFAULT_COLOR_LIST = ['#1f77b4', '#ff7f0e', '#2ca02c', '#d62728', '#9467bd', '#8c564b', '#e377c2', '#7f7f7f', '#bcbd22', '#17becf']
-
 def mpl_default_color_cyclic(idx):
     """
     Get matplotlib default color in cyclic
@@ -2072,6 +2270,4 @@ def mpl_default_color_cyclic(idx):
 
 if __name__=='__main__':
     for i_cmp_name in get_colormap_list():
-        _plot_each_colorbar(i_cmp_name)
-    
-
+        _plot_each_colorbar(i_cmp_name)
\ No newline at end of file
